@@ -80,6 +80,18 @@ gpg_err_deinit (int mode)
   _gpg_err_deinit (mode);
 }
 
+void
+gpgrt_add_emergency_cleanup (void (*f)(void))
+{
+  _gpgrt_add_emergency_cleanup (f);
+}
+
+void
+gpgrt_abort (void)
+{
+  _gpgrt_abort ();
+}
+
 const char *
 gpg_error_check_version (const char *req_version)
 {
@@ -751,6 +763,12 @@ gpgrt_realloc (void *a, size_t n)
   return _gpgrt_realloc (a, n);
 }
 
+void *
+gpgrt_reallocarray (void *a, size_t oldnmemb, size_t nmemb, size_t size)
+{
+  return _gpgrt_reallocarray (a, oldnmemb, nmemb, size);
+}
+
 void *
 gpgrt_malloc (size_t n)
 {
@@ -981,7 +999,7 @@ gpgrt_log_fatal (const char *fmt, ...)
   va_start (arg_ptr, fmt);
   _gpgrt_logv (GPGRT_LOGLVL_FATAL, fmt, arg_ptr);
   va_end (arg_ptr);
-  abort (); /* Never called; just to make the compiler happy.  */
+  _gpgrt_abort (); /* Never called; just to make the compiler happy.  */
 }
 
 void
@@ -992,7 +1010,7 @@ gpgrt_log_bug (const char *fmt, ...)
   va_start (arg_ptr, fmt);
   _gpgrt_logv (GPGRT_LOGLVL_BUG, fmt, arg_ptr);
   va_end (arg_ptr);
-  abort (); /* Never called; just to make the compiler happy.  */
+  _gpgrt_abort (); /* Never called; just to make the compiler happy.  */
 }
 
 void
@@ -1127,6 +1145,12 @@ gpgrt_argparse (estream_t fp, gpgrt_argparse_t *arg, gpgrt_opt_t *opts)
   return _gpgrt_argparse (fp, arg, opts);
 }
 
+int
+gpgrt_argparser (gpgrt_argparse_t *arg, gpgrt_opt_t *opts, const char *name)
+{
+  return _gpgrt_argparser (arg, opts, name);
+}
+
 void
 gpgrt_usage (int level)
 {
@@ -1157,6 +1181,12 @@ gpgrt_set_fixed_string_mapper (const char *(*f)(const char*))
   _gpgrt_set_fixed_string_mapper (f);
 }
 
+void
+gpgrt_set_confdir (int what, const char *name)
+{
+  _gpgrt_set_confdir (what, name);
+}
+
 
 
 /* Compare program versions.  */
@@ -1167,6 +1197,33 @@ gpgrt_cmp_version (const char *a, const char *b, int level)
 }
 
 
+
+/* String utilities.  */
+char *
+gpgrt_fnameconcat (const char *first, ... )
+{
+  va_list arg_ptr;
+  char *result;
+
+  va_start (arg_ptr, first);
+  result = _gpgrt_vfnameconcat (0, first, arg_ptr);
+  va_end (arg_ptr);
+  return result;
+}
+
+char *
+gpgrt_absfnameconcat (const char *first, ... )
+{
+  va_list arg_ptr;
+  char *result;
+
+  va_start (arg_ptr, first);
+  result = _gpgrt_vfnameconcat (1, first, arg_ptr);
+  va_end (arg_ptr);
+  return result;
+}
+
+
 
 /* For consistency reasons we use function wrappers also for Windows
  * specific function despite that they are technically not needed.  */
